@@ -104,5 +104,6 @@ class CellGeometry(object):
         else:
             # Surface area of conical frusta
             # A = pi*(r1+r2)*sqrt((r1-r2)^2 + h^2)
-            self.area = np.pi * self.d.sum(axis=-1) * \
-                np.sqrt(np.diff(self.d, axis=-1)**2 + self.length**2)
+            r = self.d / 2
+            self.area = np.pi * r.sum(axis=-1) * \
+                np.sqrt(np.diff(r, axis=-1).ravel()**2 + self.length**2)
